;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "org-index" "20250914.850"
  "Ranked and incremental search among selected org-headlines."
  '((org   "9.3")
    (dash  "2.12")
    (s     "1.12")
    (emacs "26.3"))
  :url "https://github.com/marcIhm/org-index"
  :commit "77bdcefab4cfc673844e21eaea7b446e40498ef6"
  :revdesc "77bdcefab4cf"
  :authors '(("Marc Ihm" . "marc@ihm.name"))
  :maintainers '(("Marc Ihm" . "marc@ihm.name")))
